@@ -262,7 +262,7 @@ def update_if_outdated(folder):
 
 def choose_raw_dataset(currently=""):
     """Let the user choose a raw dataset. Return the absolute path."""
-    folder = os.path.join(get_project_root(), "archive/raw-datasets")
+    folder = os.path.join(get_project_root(), "raw-datasets")
     files = [os.path.join(folder, name) for name in os.listdir(folder)
              if name.endswith(".pickle")]
     default = -1
